pub fn with_terminal<T>(f: impl FnMut(&mut CrosstermTerminal) -> T) -> Result<T>Expand description
Runs a closure with the default Foundry terminal setup.
pub fn with_terminal<T>(f: impl FnMut(&mut CrosstermTerminal) -> T) -> Result<T>Runs a closure with the default Foundry terminal setup.